@@ -1,4 +1,4 @@
-__author__ = 'bloodchilde'
+__author__ = 'Xiaoou WANG'
 
 
 def max(a, b):
